/*
 * interdiff - create incremental patch between two against a common source
 *
 * Utility functions.
 * Copyright (C) 2001  Marko Kreen
 * Copyright (C) 2001  Tim Waugh <twaugh@redhat.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#if HAVE_SYS_TYPES_H
#include <sys/types.h> // for pid_t
#endif

/* safe malloc */
void *xmalloc (size_t size);
/* safe strdup */
char *xstrdup (const char *s);
/* safe strndup */
char *xstrndup (const char *s, const size_t n);

FILE *xopen(const char *file, const char *mode);
FILE *xopen_seekable(const char *file, const char *mode);
FILE *xopen_unzip(const char *file, const char *mode);
FILE *xpipe(const char *cmd, pid_t *pid, const char *mode, ...);

struct patlist;

/* create a new item */
void patlist_add(struct patlist **dst, const char *s);
/* load whole list from file */
void patlist_add_file(struct patlist **dst, const char *fn);

/* match a string to all patterns */
int patlist_match(struct patlist *list, const char *s);

/* free rxlist */
void patlist_free(struct patlist **list);

extern char *progname;
void set_progname(const char * s);


/* for non-glibc system */
#ifndef HAVE_GETLINE
int getline(char **line, size_t *n, FILE *f);
#endif

